<?php
/**
 * Theia functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Theia Lite
 */

if ( ! function_exists( 'theia_lite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function theia_lite_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Theia, use a find and replace
	 * to change 'theia-lite' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'theia-lite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'theia-image-post' , 800, 499, true);
	add_image_size( 'theia-normal-post' , 1920, 9999);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'menu-1' => esc_html__( 'Primary', 'theia-lite' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	
	//Logo upload customizer support	
	add_theme_support( 'custom-logo', array(
		'height'      => 120,
		'width'       => 344,
		'flex-width'  => true,
	) );
	
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'theia_lite_custom_background_args', array(
		'default-color' => 'f2f3f0',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'theia_lite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function theia_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'theia_content_width', 640 );
}
add_action( 'after_setup_theme', 'theia_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function theia_lite_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'theia-lite' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'theia-lite' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'theia_lite_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function theia_lite_scripts() {
	wp_enqueue_style( 'theia-lite-style', get_stylesheet_uri() );
	
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/css/font-awesome.min.css');

	wp_enqueue_style( 'theia-lite-googlefonts', theia_lite_google_fonts_url(), array(), null );
	
	wp_enqueue_script( 'theia-lite-custom', get_template_directory_uri() . '/js/jquery.theia.js', array('jquery', 'jquery-masonry'), '1.0', true );		
	
	wp_enqueue_script( 'theia-lite-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'theia_lite_scripts' );

/**
 * Register default Google Fonts
 */
function theia_lite_google_fonts_url() {
	$font_families = array( 'Raleway:100,200,300,400,600,700','Lora:100,200,300,400,600,700','Noto Sans:100,200,300,400,600,700' );
	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);
	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	return apply_filters( 'theia_lite_google_fonts_url', $fonts_url );
}


/**
 * Custom Excerpt Length
 */
if ( ! function_exists( 'theia_lite_custom_excerpt_length' ) ) {
	function theia_lite_custom_excerpt_length( $length ) {
		if ( ! is_admin() ) {
			return 18;
		} else {
			return $length;
		}
	}
}
add_filter( 'excerpt_length', 'theia_lite_custom_excerpt_length', 999 );

/**
 * Replace Excerpt More
 */
if ( ! function_exists( 'theia_lite_new_excerpt_more' ) ) {
	function theia_lite_new_excerpt_more( $more ) {
		return '&hellip;';
	}
}
add_filter('excerpt_more', 'theia_lite_new_excerpt_more');
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Delete font size style from tag cloud widget
 */
if ( ! function_exists( 'theia_fix_tag_cloud' ) ) {
	function theia_fix_tag_cloud($tag_string){
	   return preg_replace('/ style=("|\')(.*?)("|\')/','',$tag_string);
	}
}
add_filter('wp_generate_tag_cloud', 'theia_fix_tag_cloud',10,1);
/**
 * Backwards Compatibility for wp_body_open() function in WP 5.2
 */
if ( ! function_exists( 'wp_body_open' ) ) {
        function wp_body_open() {
                do_action( 'wp_body_open' );
        }
} 
/**
 * Load PRO Button in the customizer
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/pro-button/class-customize.php' );

/* Calling in the admin area for the Welcome Page */
if ( is_admin() ) {
	require get_template_directory() . '/inc/admin/theia-lite-admin-page.php';
}
